import { AppBar, Toolbar, Typography, styled, Box, Grid } from "@mui/material";
import { Link } from "react-router-dom";
import { useAppDispatch, useAppSelector } from "../../../store/hooks.ts";
import UserMenu from "../menus/userMenu/UserMenu.tsx";
import AnonymousMenu from "../menus/anonymousMenu/AnonymousMenu.tsx";
import { logoutUser } from "../../../features/usersSlice.ts";

const StyledLink = styled(Link)(() => ({
  color: "inherit",
  textDecoration: "none",
  ["&:hover"]: { color: "inherit" },
}));

const AppToolbar = () => {
  const { user } = useAppSelector((state) => state.user);
  const dispatch = useAppDispatch();

  const logoutHandler = () => {
    dispatch(logoutUser());
  };

  return (
    <>
      <AppBar position="fixed">
        <Toolbar>
          <Grid container alignItems="center" justifyContent="space-between">
            <Typography variant="h6" component={StyledLink} to="/">
              Computer parts shop
            </Typography>
            {user ? (
              <UserMenu user={user} onLogoutHandler={logoutHandler} />
            ) : (
              <AnonymousMenu />
            )}
          </Grid>
        </Toolbar>
      </AppBar>
      <Box component={Toolbar} marginBottom={2} />
    </>
  );
};

export default AppToolbar;
