import { Grid, MenuItem, TextField } from "@mui/material";
import { ChangeEventHandler } from "react";

type Option = {
  id: string | number;
  title: string;
};

interface IProps {
  label: string;
  value: string;
  onChange: ChangeEventHandler;
  name: string;
  required?: boolean;
  error?: string;
  type?: string;
  multiline?: boolean;
  fullWidth?: boolean;
  select?: boolean;
  options?: Option[];
}
const FormElement = (props: IProps) => {
  return (
    <Grid item xs>
      <TextField
        margin="normal"
        fullWidth={props.fullWidth}
        id={props.name}
        label={props.label}
        value={props.value}
        onChange={props.onChange}
        name={props.name}
        autoComplete={props.name}
        multiline={props.multiline}
        error={!!props.error}
        helperText={props.error}
        required={props.required}
        type={props.type}
        select={props.select}
      >
        {props.select && props.options
          ? props.options.map((option) => {
              return (
                <MenuItem key={option.id} value={option.id}>
                  {option.title}
                </MenuItem>
              );
            })
          : null}
      </TextField>
    </Grid>
  );
};

export default FormElement;
