import { ChangeEvent, FormEvent, useState } from "react";
import {
  Avatar,
  Box,
  Button,
  Container,
  Grid,
  Link,
  Typography,
  Alert,
} from "@mui/material";
import { Link as RouterLink, useNavigate } from "react-router-dom";
import LockOutlinedIcon from "@mui/icons-material/LockOutlined";
import FormElement from "../../components/UI/Form/FormElement/FormElement.tsx";
import { useAppDispatch, useAppSelector } from "../../store/hooks.ts";
import { loginUser } from "../../features/usersSlice.ts";

interface IState {
  username: string;
  password: string;
}

const initialState: IState = {
  username: "",
  password: "",
};

const Login = () => {
  const dispatch = useAppDispatch();
  const navigate = useNavigate();
  const { loginError } = useAppSelector((state) => state.user);

  const [state, setState] = useState<IState>(initialState);

  const inputChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;

    setState((prevState) => ({ ...prevState, [name]: value }));
  };

  const submitFormHandler = (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();

    dispatch(loginUser({ ...state }))
      .unwrap()
      .then(() => {
        navigate("/");
      });
  };

  return (
    <Container component="main" maxWidth="xs">
      <Box
        sx={{
          marginTop: 8,
          display: "flex",
          flexDirection: "column",
          alignItems: "center",
        }}
      >
        <Avatar sx={{ m: 1, bgcolor: "secondary.main" }}>
          <LockOutlinedIcon />
        </Avatar>

        <Typography component="h1" variant="h5">
          Sign in
        </Typography>

        {loginError ? <Alert severity="error">{loginError}</Alert> : null}

        <Box
          component="form"
          onSubmit={submitFormHandler}
          noValidate
          sx={{ mt: 1 }}
        >
          <FormElement
            required
            label="Username"
            name="username"
            onChange={inputChangeHandler}
            value={state.username}
          />

          <FormElement
            required
            name="password"
            label="Password"
            type="password"
            onChange={inputChangeHandler}
            value={state.password}
          />

          <Button
            fullWidth
            type="submit"
            variant="contained"
            sx={{ mt: 3, mb: 2 }}
          >
            Sign In
          </Button>

          <Grid container>
            <Grid item>
              <Link component={RouterLink} to={"/register"} variant="body2">
                {"Don't have an account? Sign Up"}
              </Link>
            </Grid>
          </Grid>
        </Box>
      </Box>
    </Container>
  );
};

export default Login;
