import { Button, Grid, Typography } from "@mui/material";
import { Link } from "react-router-dom";
import { useAppDispatch, useAppSelector } from "../../store/hooks.ts";
import { useEffect } from "react";
import { fetchProducts } from "../../features/productsSlice.ts";
import ProductItem from "../../components/ProductItem/ProductItem.tsx";

const Products = () => {
  const dispatch = useAppDispatch();
  const { products } = useAppSelector((state) => state.products);
  const { user } = useAppSelector((state) => state.user);

  useEffect(() => {
    dispatch(fetchProducts());
  }, [dispatch]);

  return (
    <Grid container direction="column" spacing={2}>
      <Grid
        item
        container
        direction="row"
        justifyContent="space-between"
        alignItems="center"
      >
        <Grid item>
          <Typography variant="h4">Products</Typography>
        </Grid>

        {user && user.role === "admin" && (
          <Grid item>
            <Button color="primary" component={Link} to="/products/new">
              Add product
            </Button>
          </Grid>
        )}
      </Grid>
      <Grid container item spacing={2}>
        {products.map((product) => (
          <ProductItem
            key={product.id}
            title={product.title}
            price={product.price}
            id={product.id}
            image={product.image}
          />
        ))}
      </Grid>
    </Grid>
  );
};

export default Products;
