import { ICategory } from "../interfaces/ICategory.ts";
import { createAsyncThunk, createSlice } from "@reduxjs/toolkit";
import axiosApi from "../axiosApi.ts";

interface IState {
  categories: ICategory[];
  error: Error | null;
  loading: boolean;
}

const initialState: IState = {
  categories: [],
  error: null,
  loading: false,
};

export const fetchCategories = createAsyncThunk(
  "fetch/categories",
  async () => {
    return await axiosApi
      .get<ICategory[]>("/categories")
      .then((res) => res.data);
  },
);

const categoriesSlice = createSlice({
  name: "categories",
  initialState,
  reducers: {},
  extraReducers: (builder) => {
    builder
      .addCase(fetchCategories.pending, (state) => {
        state.loading = true;
        state.error = null;
      })
      .addCase(fetchCategories.fulfilled, (state, action) => {
        state.categories = action.payload;
        state.loading = false;
      })
      .addCase(fetchCategories.rejected, (state, action) => {
        state.error = action.error as Error;
        state.loading = false;
      });
  },
});

export default categoriesSlice.reducer;
