import { createAsyncThunk, createSlice } from "@reduxjs/toolkit";
import { IProduct } from "../interfaces/IProduct.ts";
import axiosApi from "../axiosApi.ts";

interface IState {
  products: IProduct[];
  error: Error | null;
  loading: boolean;
}
const initialState: IState = {
  products: [],
  error: null,
  loading: false,
};

export const fetchProducts = createAsyncThunk("fetch/products", async () => {
  return axiosApi.get<IProduct[]>("/products").then((res) => res.data);
});

export const createProduct = createAsyncThunk(
  "create/products",
  async (payload: FormData) => {
    return await axiosApi.post("/products", payload).then((res) => res.data);
  },
);

const productsSlice = createSlice({
  name: "products",
  initialState,
  reducers: {},
  extraReducers: (builder) => {
    builder
      .addCase(fetchProducts.fulfilled, (state, action) => {
        state.products = action.payload;
        state.loading = false;
      })
      .addCase(fetchProducts.rejected, (state, action) => {
        state.error = action.error as Error;
        state.loading = false;
      })
      .addCase(fetchProducts.pending, (state) => {
        state.error = null;
        state.loading = true;
      });
  },
});

export default productsSlice.reducer;
